@@ -195,6 +195,9 @@ class QuickBooks(object):
                 """
             ) % (boundary, request_body, boundary, content_type, binary_data, boundary)
 
+            # make sure request_body is not unicode (python 2 case)
+            request_body = str(request_body)
+
         req = self.process_request(request_type, url, headers=headers, params=params, data=request_body)
 
         if req.status_code == httplib.UNAUTHORIZED:
@@ -290,6 +293,12 @@ class QuickBooks(object):
 
         return results
 
+    def misc_operation(self, end_point, request_body):
+        url = self.api_url + "/company/{0}/{1}".format(self.company_id, end_point)
+        results = self.make_request("POST", url, request_body)
+
+        return results
+
     def download_pdf(self, qbbo, item_id):
         if self.session_manager is None:
             raise QuickbooksException('No session manager')
