@@ -5,16 +5,19 @@ from .base import Ref, QuickbooksManagedObject, QuickbooksTransactionEntity
 @python_2_unicode_compatible
 class Item(QuickbooksManagedObject, QuickbooksTransactionEntity):
     """
-    QBO definition: An item is a thing that your company buys, sells, or re-sells, such as products and services.
-    An item is shown as a line on an invoice or other sales form. The Item.Type attribute, which specifies how
-    the item is used, has one of the following values:
+    QBO definition: An item is a thing that your company buys, sells, or re-sells,
+    such as products and services. An item is shown as a line on an invoice or other sales
+    form. The Item.Type attribute, which specifies how the item is used, has one of
+    the following values:
 
-    Inventory - This type tracks merchandise that your business purchases, stocks, and re-sells as inventory.
-    QuickBooks tracks the current number of inventory items in stock, cost of goods sold, and the asset value of
-    the inventory after the purchase and sale of every item.
+    Inventory - This type tracks merchandise that your business purchases, stocks,
+    and re-sells as inventory. QuickBooks tracks the current number of inventory items in stock,
+    cost of goods sold, and the asset value of the inventory after the purchase and sale
+    of every item.
 
-    Service - This type tracks services that you charge on the purchase and tracks merchandise you sell and buy that
-    is not tracked as inventory. For example, specialized labor, consulting hours, and professional fees.
+    Service - This type tracks services that you charge on the purchase and tracks
+    merchandise you sell and buy that is not tracked as inventory. For example, specialized
+    labor, consulting hours, and professional fees.
     """
 
     class_dict = {
@@ -36,12 +39,12 @@ class Item(QuickbooksManagedObject, QuickbooksTransactionEntity):
         self.SubItem = False
         self.FullyQualifiedName = ""  # Readonly
         self.Taxable = False
-        self.SalesTaxInclusive = None
+        self.SalesTaxIncluded = None
         self.UnitPrice = 0
         self.Type = ""
         self.Level = None  # Readonly
         self.PurchaseDesc = None
-        self.PurchaseTaxInclusive = None
+        self.PurchaseTaxIncluded = None
         self.PurchaseCost = None
         self.TrackQtyOnHand = False
         self.QtyOnHand = None
@@ -74,4 +77,3 @@ class Item(QuickbooksManagedObject, QuickbooksTransactionEntity):
         ref.value = self.Id
 
         return ref
-
