@@ -3,6 +3,7 @@ from .base import QuickbooksBaseObject, Ref, QuickbooksManagedObject, Quickbooks
     LinkedTxnMixin
 from .tax import TxnTaxDetail
 from .detailline import DetailLine, DescriptionOnlyLine
+from ..mixins import DeleteMixin
 
 
 class Entity(QuickbooksBaseObject):
@@ -51,7 +52,7 @@ class JournalEntryLine(DetailLine):
 
 
 @python_2_unicode_compatible
-class JournalEntry(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMixin):
+class JournalEntry(DeleteMixin, QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMixin):
     """
     QBO definition: Journal Entry is a transaction in which:
         - There are at least two parts - a Debit and a Credit - called distribution lines.
